Branch: master

4efcfec9 2014-09-26 10:01:09 Slávek Banko
Use TDE data source for new stuff
M amarok/src/Options2.ui.h
M amarok/src/amarokrc
M amarok/src/scriptmanager.cpp
diff --git a/amarok/src/amarokrc b/amarok/src/amarokrc
index 1f0f49f..8a41af3 100644
--- a/amarok/src/amarokrc
+++ b/amarok/src/amarokrc
@@ -8,7 +8,7 @@
 #see PlaylistWidget::setColumnWidth() for explanation for below
 ColumnWidths=0,200,100,100,0,0,0,0,0,80,0
 
-[KNewStuff]
+[TDENewStuff]
 TargetDir=amarok/themes
 Uncompress=application/x-gzip
-ProvidersUrl=http://amarok.kde.org/knewstuff/amarokthemes-providers.xml
+ProvidersUrl=https://www.trinitydesktop.org/ocs/providers.xml
diff --git a/amarok/src/Options2.ui.h b/amarok/src/Options2.ui.h
index a6793b6..57e65de 100644
--- a/amarok/src/Options2.ui.h
+++ b/amarok/src/Options2.ui.h
@@ -18,10 +18,10 @@
 #include <tdeapplication.h>
 #include <tdefiledialog.h>
 #include <tdemessagebox.h>
-#include <knewstuff/downloaddialog.h> // knewstuff theme fetching
-#include <knewstuff/engine.h>         // "
-#include <knewstuff/knewstuff.h>      // "
-#include <knewstuff/provider.h>       // "
+#include <tdenewstuff/downloaddialog.h> // tdenewstuff theme fetching
+#include <tdenewstuff/engine.h>         // "
+#include <tdenewstuff/knewstuff.h>      // "
+#include <tdenewstuff/provider.h>       // "
 #include <kstandarddirs.h>
 #include <ktar.h>
 #include <tdeio/netaccess.h>
@@ -38,11 +38,11 @@
 /**
  * GHNS Customised Download implementation.
  */
-class AmarokThemeNewStuff : public KNewStuff
+class AmarokThemeNewStuff : public TDENewStuff
 {
     public:
     AmarokThemeNewStuff(const TQString &type, TQWidget *parentWidget=0)
-             : KNewStuff( type, parentWidget )
+             : TDENewStuff( type, parentWidget )
     {}
 
     bool install( const TQString& fileName )
@@ -105,12 +105,12 @@
 
 void Options2::retrievePushButton_clicked()
 {
     // Delete KNewStuff's configuration entries. These entries reflect which styles
     // are already installed. As we cannot yet keep them in sync after uninstalling
     // styles, we deactivate the check marks entirely.
-    Amarok::config()->deleteGroup( "KNewStuffStatus" );
+    Amarok::config()->deleteGroup( "TDENewStuffStatus" );
 
     // we need this because KNewStuffGeneric's install function isn't clever enough
     AmarokThemeNewStuff *kns = new AmarokThemeNewStuff( "amarok/themes", this );
     KNS::Engine *engine = new KNS::Engine( kns, "amarok/theme", this );
     KNS::DownloadDialog* d = new KNS::DownloadDialog( engine, this );
@@ -118,7 +118,7 @@
     // you have to do this by hand when providing your own Engine
     KNS::ProviderLoader *p = new KNS::ProviderLoader( this );
     connect( p, TQT_SIGNAL( providersLoaded(Provider::List*) ), d, TQT_SLOT( slotProviders(Provider::List *) ) );
-    p->load( "amarok/theme", "http://amarok.kde.org/knewstuff/amarokthemes-providers.xml" );
+    p->load( "amarok theme", "https://www.trinitydesktop.org/ocs/providers.xml" );
 
     connect( d, TQT_SIGNAL( finished() ), d, TQT_SLOT( delayedDestruct() ) );
     connect( d, TQT_SIGNAL( finished() ), this, TQT_SLOT( updateStyleComboBox() ) );
@@ -105,12 +105,12 @@
 void Options2::retrievePushButton_clicked()
 {
-    // Delete KNewStuff's configuration entries. These entries reflect which styles
+    // Delete TDENewStuff's configuration entries. These entries reflect which styles
     // are already installed. As we cannot yet keep them in sync after uninstalling
     // styles, we deactivate the check marks entirely.
@@ -105,12 +105,12 @@
 
-    // we need this because KNewStuffGeneric's install function isn't clever enough
+    // we need this because TDENewStuffGeneric's install function isn't clever enough
     AmarokThemeNewStuff *kns = new AmarokThemeNewStuff( "amarok/themes", this );
     KNS::Engine *engine = new KNS::Engine( kns, "amarok/theme", this );
diff --git a/amarok/src/scriptmanager.cpp b/amarok/src/scriptmanager.cpp
index c9abc2f..dbdfdc3 100644
--- a/amarok/src/scriptmanager.cpp
+++ b/amarok/src/scriptmanager.cpp
@@ -61,10 +61,10 @@
 #include <ktextedit.h>
 #include <twin.h>
 
-#include <knewstuff/downloaddialog.h> // knewstuff script fetching
-#include <knewstuff/engine.h>         // "
-#include <knewstuff/knewstuff.h>      // "
-#include <knewstuff/provider.h>       // "
+#include <tdenewstuff/downloaddialog.h> // tdenewstuff script fetching
+#include <tdenewstuff/engine.h>         // "
+#include <tdenewstuff/knewstuff.h>      // "
+#include <tdenewstuff/provider.h>       // "
 
 
 namespace Amarok {
@@ -111,11 +111,11 @@
 /**
  * GHNS Customised Download implementation.
  */
-class AmarokScriptNewStuff : public KNewStuff
+class AmarokScriptNewStuff : public TDENewStuff
 {
     public:
     AmarokScriptNewStuff(const TQString &type, TQWidget *parentWidget=0)
-             : KNewStuff( type, parentWidget )
+             : TDENewStuff( type, parentWidget )
     {}
 
     bool install( const TQString& fileName )
@@ -488,12 +488,12 @@
 void
 ScriptManager::slotRetrieveScript()
 {
     // Delete KNewStuff's configuration entries. These entries reflect which scripts
     // are already installed. As we cannot yet keep them in sync after uninstalling
     // scripts, we deactivate the check marks entirely.
-    Amarok::config()->deleteGroup( "KNewStuffStatus" );
+    Amarok::config()->deleteGroup( "TDENewStuffStatus" );
 
     // we need this because KNewStuffGeneric's install function isn't clever enough
     AmarokScriptNewStuff *kns = new AmarokScriptNewStuff( "amarok/script", this );
     KNS::Engine *engine = new KNS::Engine( kns, "amarok/script", this );
     KNS::DownloadDialog *d = new KNS::DownloadDialog( engine, this );
@@ -501,7 +501,7 @@
     // you have to do this by hand when providing your own Engine
     KNS::ProviderLoader *p = new KNS::ProviderLoader( this );
     TQObject::connect( p, TQT_SIGNAL( providersLoaded(Provider::List*) ), d, TQT_SLOT( slotProviders (Provider::List *) ) );
-    p->load( "amarok/script", "http://amarok.kde.org/knewstuff/amarokscripts-providers.xml" );
+    p->load( "amarok script", "https://www.trinitydesktop.org/ocs/providers.xml" );
 
     d->exec();
 }
@@ -488,12 +488,12 @@
 ScriptManager::slotRetrieveScript()
 {
-    // Delete KNewStuff's configuration entries. These entries reflect which scripts
+    // Delete TDENewStuff's configuration entries. These entries reflect which scripts
     // are already installed. As we cannot yet keep them in sync after uninstalling
     // scripts, we deactivate the check marks entirely.
@@ -488,12 +488,12 @@
 
-    // we need this because KNewStuffGeneric's install function isn't clever enough
+    // we need this because TDENewStuffGeneric's install function isn't clever enough
     AmarokScriptNewStuff *kns = new AmarokScriptNewStuff( "amarok/script", this );
     KNS::Engine *engine = new KNS::Engine( kns, "amarok/script", this );